Mnemonex (Mnemonex v1.2.4)

Copy Markdown View Source

Mnemonex application

Summary

Types

A keyword list with output formatting options

Functions

decode a mnemonicoded word list

application start

Types

coder_options()

@type coder_options() :: [
  name: atom(),
  as_list: boolean(),
  words_per_group: pos_integer(),
  word_separator: String.t(),
  groups_per_line: pos_integer(),
  group_separator: String.t(),
  line_prefix: String.t(),
  line_suffix: String.t()
]

A keyword list with output formatting options

  • name: registered process name (default: :mnx_coder)
  • as_list: return a list of unformatted words (default: false)
  • words_per_group: words per output group (default: 3)
  • word_separator: combining words in a group (default: -)
  • groups_per_line: groups per output line (default: 2)
  • group_separator: combining groups in a line (default: --)
  • line_prefix: prepended to each output line (default: empty string)
  • line_suffix: appended to each output line (default: )

Functions

decode(input, server \\ :mnx_coder)

@spec decode(binary(), term()) :: binary()

decode a mnemonicoded word list

All non-alphabetic (ASCII) characters are treated as word breaks. There is presently no graceful handling of improperly entered words.

encode(input, server \\ :mnx_coder)

@spec encode(binary() | pos_integer(), term()) :: binary()

encode a binary

Unsigned big-endian integers may also be encoded, but note that there is presently no affordance to decode them back to same.

The output format depends on configuration variables (described therein.)

start(type, opts \\ [])

application start